import { Component, ViewEncapsulation, ChangeDetectionStrategy, Input, ViewChild, NgModule } from '@angular/core';
import { highlight, languages } from 'prismjs';
import { CommonModule } from '@angular/common';

class NgxCodeHighlightComponent {
    constructor() {
        this.language = 'javascript';
        this.safeHtml = '';
    }
    ngOnInit() {
        const html = this.ref.nativeElement.innerHTML
            .replace(/\{ \{/gi, '{{')
            .replace(/\} \}/gi, '}}')
            .replace(/&lt;/gi, '<')
            .replace(/&gt;/gi, '>');
        this.safeHtml = highlight(html, languages[this.language]);
    }
}
NgxCodeHighlightComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-code-highlight',
                template: "<div class=\"code-highlight\">\r\n  <pre [className]=\"'language-' + language\" class=\"margin-top\">\r\n    <code [className]=\"'language-' + language\" [innerHTML]=\"safeHtml\"></code>\r\n  </pre>\r\n  <div #code class=\"display-none\" hidden>\r\n    <ng-content></ng-content>\r\n  </div>\r\n</div>",
                encapsulation: ViewEncapsulation.None,
                preserveWhitespaces: true,
                changeDetection: ChangeDetectionStrategy.Default,
                styles: [".code-highlight code{display:block;margin:-60px 0 -80px}.code-highlight pre{border-left:5px solid;margin:20px 0;overflow:hidden;padding:0 20px}"]
            },] }
];
NgxCodeHighlightComponent.propDecorators = {
    language: [{ type: Input }],
    ref: [{ type: ViewChild, args: ['code', { static: true },] }]
};

class NgxCodeHighlightModule {
}
NgxCodeHighlightModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [NgxCodeHighlightComponent],
                exports: [NgxCodeHighlightComponent]
            },] }
];

/*
 * Public API Surface of ngx-code-highlight
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxCodeHighlightComponent, NgxCodeHighlightModule };
//# sourceMappingURL=ngx-tiny-code-highlight.js.map
